// androidqf - Android Quick Forensics
// Copyright (c) 2021 Claudio Guarnieri.
// Use of this software is governed by the MVT License 1.1 that can be found at
//   https://license.mvt.re/1.1/

package acquisition

var packageFilter []string = []string{
	"android",
	"android.auto_generated_rro__",
	"android.autoinstalls.config.google.nexus",
	"com.android.backupconfirm",
	"com.android.bips",
	"com.android.bluetooth",
	"com.android.bluetoothmidiservice",
	"com.android.bookmarkprovider",
	"com.android.calllogbackup",
	"com.android.captiveportallogin",
	"com.android.carrierconfig",
	"com.android.carrierdefaultapp",
	"com.android.cellbroadcastreceiver",
	"com.android.certinstaller",
	"com.android.chrome",
	"com.android.companiondevicemanager",
	"com.android.connectivity.metrics",
	"com.android.cts.ctsshim",
	"com.android.cts.priv.ctsshim",
	"com.android.defcontainer",
	"com.android.documentsui",
	"com.android.dreams.basic",
	"com.android.egg",
	"com.android.emergency",
	"com.android.externalstorage",
	"com.android.facelock",
	"com.android.hotwordenrollment",
	"com.android.hotwordenrollment.okgoogle",
	"com.android.hotwordenrollment.tgoogle",
	"com.android.hotwordenrollment.xgoogle",
	"com.android.htmlviewer",
	"com.android.inputdevices",
	"com.android.keychain",
	"com.android.location.fused",
	"com.android.managedprovisioning",
	"com.android.mms.service",
	"com.android.mtp",
	"com.android.musicfx",
	"com.android.nfc",
	"com.android.omadm.service",
	"com.android.pacprocessor",
	"com.android.phone",
	"com.android.printspooler",
	"com.android.providers.blockednumber",
	"com.android.providers.calendar",
	"com.android.providers.contacts",
	"com.android.providers.downloads",
	"com.android.providers.downloads.ui",
	"com.android.providers.media",
	"com.android.providers.partnerbookmarks",
	"com.android.providers.settings",
	"com.android.providers.telephony",
	"com.android.providers.userdictionary",
	"com.android.proxyhandler",
	"com.android.retaildemo",
	"com.android.safetyregulatoryinfo",
	"com.android.sdm.plugins.connmo",
	"com.android.sdm.plugins.dcmo",
	"com.android.sdm.plugins.diagmon",
	"com.android.sdm.plugins.sprintdm",
	"com.android.server.telecom",
	"com.android.service.ims",
	"com.android.service.ims.presence",
	"com.android.settings",
	"com.android.sharedstoragebackup",
	"com.android.shell",
	"com.android.statementservice",
	"com.android.stk",
	"com.android.systemui",
	"com.android.systemui.theme.dark",
	"com.android.vending",
	"com.android.vpndialogs",
	"com.android.vzwomatrigger",
	"com.android.wallpaperbackup",
	"com.android.wallpaper.livepicker",
	"com.breel.wallpapers",
	"com.customermobile.preload.vzw",
	"com.google.android.apps.cloudprint",
	"com.google.android.apps.docs",
	"com.google.android.apps.docs.editors.docs",
	"com.google.android.apps.enterprise.dmagent",
	"com.google.android.apps.gcs",
	"com.google.android.apps.helprtc",
	"com.google.android.apps.inputmethod.hindi",
	"com.google.android.apps.maps",
	"com.google.android.apps.messaging",
	"com.google.android.apps.nexuslauncher",
	"com.google.android.apps.photos",
	"com.google.android.apps.pixelmigrate",
	"com.google.android.apps.tachyon",
	"com.google.android.apps.turbo",
	"com.google.android.apps.tycho",
	"com.google.android.apps.wallpaper",
	"com.google.android.apps.wallpaper.nexus",
	"com.google.android.apps.work.oobconfig",
	"com.google.android.apps.youtube.vr",
	"com.google.android.asdiv",
	"com.google.android.backuptransport",
	"com.google.android.calculator",
	"com.google.android.calendar",
	"com.google.android.carrier",
	"com.google.android.carrier.authdialog",
	"com.google.android.carrierentitlement",
	"com.google.android.carriersetup",
	"com.google.android.configupdater",
	"com.google.android.contacts",
	"com.google.android.deskclock",
	"com.google.android.dialer",
	"com.google.android.euicc",
	"com.google.android.ext.services",
	"com.google.android.ext.shared",
	"com.google.android.feedback",
	"com.google.android.gm",
	"com.google.android.gms",
	"com.google.android.gms.policy_auth",
	"com.google.android.gms.policy_sidecar_o",
	"com.google.android.gms.setup",
	"com.google.android.GoogleCamera",
	"com.google.android.googlequicksearchbox",
	"com.google.android.gsf",
	"com.google.android.gsf.login",
	"com.google.android.hardwareinfo",
	"com.google.android.hiddenmenu",
	"com.google.android.ims",
	"com.google.android.inputmethod.japanese",
	"com.google.android.inputmethod.korean",
	"com.google.android.inputmethod.latin",
	"com.google.android.inputmethod.pinyin",
	"com.google.android.instantapps.supervisor",
	"com.google.android.keep",
	"com.google.android.marvin.talkback",
	"com.google.android.music",
	"com.google.android.nexusicons",
	"com.google.android.onetimeinitializer",
	"com.google.android.packageinstaller",
	"com.google.android.partnersetup",
	"com.google.android.printservice.recommendation",
	"com.google.android.setupwizard",
	"com.google.android.soundpicker",
	"com.google.android.storagemanager",
	"com.google.android.syncadapters.contacts",
	"com.google.android.tag",
	"com.google.android.talk",
	"com.google.android.tetheringentitlement",
	"com.google.android.theme.pixel",
	"com.google.android.tts",
	"com.google.android.videos",
	"com.google.android.vr.home",
	"com.google.android.vr.inputmethod",
	"com.google.android.webview",
	"com.google.android.wfcactivation",
	"com.google.android.youtube",
	"com.google.ar.core",
	"com.google.intelligence.sense",
	"com.google.modemservice",
	"com.google.pixel.wahoo.gfxdrv",
	"com.google.SSRestartDetector",
	"com.google.tango",
	"com.google.vr.apps.ornament",
	"com.google.vr.vrcore",
	"com.htc.omadm.trigger",
	"com.qti.qualcomm.datastatusnotification",
	"com.qualcomm.atfwd",
	"com.qualcomm.embms",
	"com.qualcomm.fastdormancy",
	"com.qualcomm.ltebc_vzw",
	"com.qualcomm.qcrilmsgtunnel",
	"com.qualcomm.qti.ims",
	"com.qualcomm.qti.networksetting",
	"com.qualcomm.qti.telephonyservice",
	"com.qualcomm.qti.uceShimService",
	"com.qualcomm.shutdownlistner",
	"com.qualcomm.timeservice",
	"com.qualcomm.vzw_api",
	"com.quicinc.cne.CNEService",
	"com.verizon.llkagent",
	"com.verizon.mips.services",
	"com.verizon.obdm",
	"com.verizon.obdm_permissions",
	"com.verizon.services",
	"com.vzw.apnlib",
	"qualcomm.com.vzw_msdc_api",
}
